==> bacula-3.0.3.tar.gz: bacula-3.0.3/src/lib/lib.h <==
/*
   Bacula® - The Network Backup Solution

   Copyright (C) 2000-2008 Free Software Foundation Europe e.V.

   The main author of Bacula is Kern Sibbald, with contributions from
   many others, a complete list can be found in the file AUTHORS.
   This program is Free Software; you can redistribute it and/or
   modify it under the terms of version two of the GNU General Public
   License as published by the Free Software Foundation and included
   in the file LICENSE.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
   02110-1301, USA.

   Bacula® is a registered trademark of Kern Sibbald.
   The licensor of Bacula is the Free Software Foundation Europe
   (FSFE), Fiduciary Program, Sumatrastrasse 25, 8006 Zürich,
   Switzerland, email:ftf@fsfeurope.org.
*/
/*
 *   Library includes for Bacula lib directory
 *
 *   This file contains an include for each library file
 *   that we use within Bacula. bacula.h includes this
 *   file and thus picks up everything we need in lib.
 *
 *   Version $Id$
 */

#include "smartall.h"
#include "lockmgr.h"
#include "alist.h"
#include "dlist.h"
#include "rblist.h"
#include "base64.h"
#include "bits.h"
#include "btime.h"
#include "crypto.h"
#include "mem_pool.h"
#include "rwlock.h"
#include "queue.h"
#include "serial.h"
#include "message.h"
#include "openssl.h"
#include "lex.h"
#include "parse_conf.h"
#include "tls.h"
#include "address_conf.h"
#include "bsock.h"
#include "workq.h"
#ifndef HAVE_FNMATCH
#include "fnmatch.h"
#endif
#include "md5.h"
#include "sha1.h"
#include "tree.h"
#include "watchdog.h"
#include "btimers.h"
#include "berrno.h"
#include "bpipe.h"
#include "attr.h"
#include "var.h"
#include "guid_to_name.h"

#include "protos.h"

==> bacula-5.2.2.tar.gz: bacula-5.2.2/src/lib/lib.h <==
/*
   Bacula® - The Network Backup Solution

   Copyright (C) 2000-2008 Free Software Foundation Europe e.V.

   The main author of Bacula is Kern Sibbald, with contributions from
   many others, a complete list can be found in the file AUTHORS.
   This program is Free Software; you can redistribute it and/or
   modify it under the terms of version three of the GNU Affero General Public
   License as published by the Free Software Foundation and included
   in the file LICENSE.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
   General Public License for more details.

   You should have received a copy of the GNU Affero General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
   02110-1301, USA.

   Bacula® is a registered trademark of Kern Sibbald.
   The licensor of Bacula is the Free Software Foundation Europe
   (FSFE), Fiduciary Program, Sumatrastrasse 25, 8006 Zürich,
   Switzerland, email:ftf@fsfeurope.org.
*/
/*
 *   Library includes for Bacula lib directory
 *
 *   This file contains an include for each library file
 *   that we use within Bacula. bacula.h includes this
 *   file and thus picks up everything we need in lib.
 *
 *   Version $Id$
 */

#include "smartall.h"
#include "lockmgr.h"
#include "alist.h"
#include "dlist.h"
#include "rblist.h"
#include "base64.h"
#include "bits.h"
#include "btime.h"
#include "crypto.h"
#include "mem_pool.h"
#include "rwlock.h"
#include "queue.h"
#include "serial.h"
#include "message.h"
#include "openssl.h"
#include "lex.h"
#include "parse_conf.h"
#include "tls.h"
#include "address_conf.h"
#include "bsock.h"
#include "workq.h"
#ifndef HAVE_FNMATCH
#include "fnmatch.h"
#endif
#include "md5.h"
#include "sha1.h"
#include "tree.h"
#include "watchdog.h"
#include "btimers.h"
#include "berrno.h"
#include "bpipe.h"
#include "attr.h"
#include "var.h"
#include "guid_to_name.h"
#include "htable.h"
#include "protos.h"
